@@ -625,17 +625,18 @@ object RClient {
   }
 
   private val defaultArguments = OS match {
-    case "windows" =>    Array[String]("--vanilla","--silent","--slave","--ess") 
-    case "linux" =>      Array[String]("--vanilla","--silent","--slave","--interactive")
-    case "unix" =>       Array[String]("--vanilla","--silent","--slave","--interactive")
-    case "macintosh" =>  Array[String]("--vanilla","--silent","--slave","--interactive")
+    case "windows" =>  Array[String]("--vanilla","--silent","--slave") 
+    case _ =>          Array[String]("--vanilla","--silent","--slave")
+  }
+
+  private val interactiveArguments = OS match {
+    case "windows" =>  Array[String]("--ess") 
+    case _ =>          Array[String]("--interactive")
   }
 
   private lazy val defaultRCmd = OS match {
-    case "windows" =>   findROnWindows
-    case "linux" =>     """R"""
-    case "unix" =>      """R"""
-    case "macintosh" => """R"""
+    case "windows" =>  findROnWindows
+    case _ =>          """R"""
   }
 
   private def findROnWindows: String = {
@@ -676,7 +677,7 @@ object RClient {
   */
   def apply(rCmd: String, debug: Boolean = false, timeout: Int = 60): RClient = {
     var cmd: PrintWriter = null
-    val command = rCmd +: defaultArguments
+    val command = rCmd +: ( defaultArguments ++ interactiveArguments )
     val processCmd = Process(command)
     val debugger = new Debugger(debug)
     val processIO = new ProcessIO(
@@ -685,23 +686,27 @@ object RClient {
       reader(debugger,"STDERR DEBUG: "),
       true
     )
-    val portsFile = File.createTempFile("rscala-","")
     val processInstance = processCmd.run(processIO)
+    val codeInR = Seq("common.R","globals.R","protocol.R","rServer.R","scalaInterpreter.R","zzz.R").map(resource => {
+      scala.io.Source.fromInputStream(getClass.getResourceAsStream("/R/"+resource)).getLines.mkString("\n")
+    }).mkString("\n\n")
+    val allCodeInR = s"""
+      rscala <- local({
+        ${codeInR}
+        environment()
+      })"""
+    val portsFile = File.createTempFile("rscala-","")
     val snippet = s"""
-rscala:::rServe(rscala:::newSockets('${portsFile.getAbsolutePath.replace(File.separator,"/")}',debug=${if ( debug ) "TRUE" else "FALSE"},timeout=${timeout}))
-q(save='no')
-    """
+      ${allCodeInR}
+      rscala[['rServe']](rscala[['newSockets']]('${portsFile.getAbsolutePath.replace(File.separator,"/")}',debug=${if ( debug ) "TRUE" else "FALSE"},timeout=${timeout}))
+      q(save='no')
+    """.stripMargin
     while ( cmd == null ) Thread.sleep(100)
     cmd.println(snippet)
     cmd.flush()
     val sockets = new ScalaSockets(portsFile.getAbsolutePath,debugger)
     sockets.out.writeInt(OK)
     sockets.out.flush()
-    try {
-      assert( Helper.readString(sockets.in) == org.ddahl.rscala.server.Version )
-    } catch {
-      case _: Throwable => throw new RuntimeException("The JAR file is not compatible with installed version of the rscala package.  Use the JAR indicated running `rscala::rscalaJar("+util.Properties.versionString.replaceFirst("""\.\d+$""","")+")` in R.")
-    }
     apply(sockets.in,sockets.out,debugger)
   }
 
