@@ -19,11 +19,6 @@ class ScalaServer private (repl: InterpreterAdapter, portsFilename: String, debu
   } else {
     out.writeInt(OK)
     out.flush
-    try {
-      assert( Helper.readString(in) == org.ddahl.rscala.server.Version )
-    } catch {
-      case _: Throwable => throw new RuntimeException("The JAR file is not compatible with installed version of the rscala package.  Use the JAR indicated running `rscala::rscalaJar("+util.Properties.versionString.replaceFirst("""\.\d+$""","")+")` in R.")
-    }
     repl.bind("R","org.ddahl.rscala.callback.RClient",R)
     if ( repl.interpreter.isInstanceOf[scala.tools.nsc.interpreter.IMain] ) {
       repl.bind("$intp","scala.tools.nsc.interpreter.IMain",repl.interpreter)
